# 🧠 PROGEN-AI: Evaluating the Impact of Generative AI in Programming Education

## 🔎 Functionality Summary

This repository contains all materials and code used in an educational experiment evaluating the effectiveness of **Amazon CodeWhisperer** as a generative AI tool to support programming education. The experiment was conducted with students enrolled in the *Programming for Data Science* course of the Master's in Data Science program at Universidad Politécnica de Madrid.

---

## 🔬 1. Educational Experiment Analysis Module

A Jupyter notebook that analyzes students’ performance in solving programming exercises **with and without** the use of generative AI (Amazon CodeWhisperer). The core of the experiment includes:

- 🧪 Solving two tasks:
  - Task 1: Without any AI assistance
  - Task 2: With Amazon CodeWhisperer

- 📊 Comparative evaluation on:
  - Accuracy in programming tasks
  - Quality of data visualizations
  - Time spent
  - Reasoning and analysis quality
  - Influence of academic background

- 📈 Result visualizations:
  - Bar plots and distributions
  - AI-assisted vs. manual coding comparisons

Results are derived from student responses collected via Microsoft Forms and processed in the notebook `Results experiment Code Wihsperer- PROGEN-AI.ipynb`.

📂 For a full description of the methodology and findings, see the notebook in the root directory.

---

## 🧬 2. Analysis Dataset: `Sales.csv`

The experiment is based on a real-world dataset of mobile phone sales, including features such as:

- Brand
- Price
- Storage capacity
- Rating

Students used this dataset to solve data filtering, analysis, and visualization tasks in both assignments.

---

## ▶️ How to Run the Experiment Analysis

1. Ensure you have Python 3.8+ and Jupyter Notebook installed.
2. Clone the repository:
   ```bash
   git clone https://gitlab.com/b.otero/codewhisperer-progen-ai.git
   cd progen-ai
   ```
3. Create the environment with Conda:
   ```bash
   conda env create -f environment.yml
   conda activate progen-ai
   ```
4. Launch the notebook:
   ```bash
   jupyter notebook
   ```
   Then open and run `Results experiment Code Wihsperer- PROGEN-AI.ipynb`.

---

## 📁 Project Structure

```
📦 progen-ai/
├── data/
│   └── Sales.csv                     # Mobile phone sales dataset
├── results/
│   └── *.csv / *.xlsx                # Form responses and analysis metrics
├── Results experiment Code Wihsperer- PROGEN-AI.ipynb   # Main analysis notebook
├── environment.yml                   # Conda environment definition
└── README.md                         # This file
```

---

## ⚙️ Environment Setup

To install dependencies:

```bash
conda env create -f environment.yml
conda activate progen-ai
```

---

## 👩‍🔬 Authors and Credits

This project was developed within an educational innovation initiative by:

- **Belén Otero-Carrasco**, Laura Melgar-García, Guillermo Vigueras, Belén Ríos  
  MEDAL · https://medal.ctb.upm.es  

